# Changelog

## 0.0.1-alpha (2025-11-25)

Full Changelog: [v0.0.1...v0.0.1-alpha](https://github.com/GetSafetyKit/safetykit-python/compare/v0.0.1...v0.0.1-alpha)

### Features

* **api:** api update ([fd9dc0a](https://github.com/GetSafetyKit/safetykit-python/commit/fd9dc0aa94e19846df4272d5ccabeb195c1f1976))
* **api:** api update ([7e2c261](https://github.com/GetSafetyKit/safetykit-python/commit/7e2c261efe218b5084b805ba73435e86547e91d1))
* **api:** api update ([6f967c9](https://github.com/GetSafetyKit/safetykit-python/commit/6f967c947e4d3793a5bcedf304ef0d7d740abdd7))
* **api:** api update ([3abe2b8](https://github.com/GetSafetyKit/safetykit-python/commit/3abe2b8617abf007de6a6e7a2539733980f272ce))
* **api:** api update ([171b3f7](https://github.com/GetSafetyKit/safetykit-python/commit/171b3f74563bb287a114f4f49983f672ef33f7a3))
* **api:** api update ([c8fcc5b](https://github.com/GetSafetyKit/safetykit-python/commit/c8fcc5b624218d254da5b93c5dac123e3f1e40f6))
* **api:** api update ([67ec9fc](https://github.com/GetSafetyKit/safetykit-python/commit/67ec9fca9ba6d30b426b64c513dd716a2692d4d5))
* **api:** api update ([3b9daed](https://github.com/GetSafetyKit/safetykit-python/commit/3b9daedf2d2ceb7e2afd6e7bf2e36929f8122e02))
* **api:** manual updates ([2333498](https://github.com/GetSafetyKit/safetykit-python/commit/23334980c06ba4098bc74f2ef41bbc06b43256ac))


### Chores

* add Python 3.14 classifier and testing ([b702cde](https://github.com/GetSafetyKit/safetykit-python/commit/b702cdeeab5728f4d6b2af6b69008c210fc637bd))
* update SDK settings ([e66de9f](https://github.com/GetSafetyKit/safetykit-python/commit/e66de9f8fc51fd3e81365e5ce65b16322cdab598))
* update SDK settings ([d79f0ee](https://github.com/GetSafetyKit/safetykit-python/commit/d79f0ee3b568159586216b4ab07a7d4797382ffb))
